#!/usr/bin/env sh

set -ox errexit
if [ -z "${POD_NAME}" ]; then
    echo "Environment variable POD_NAME not found..."
    env
    exit
fi

pod_name=${POD_NAME}
id=${pod_name##*-};
component_name=${POD_NAME%-*}

if [ -e "/mnt/config/pod/${component_name}/template.jsonnet" ]; then
  cat < /mnt/config/pod/"${component_name}"/template.jsonnet | base64 -d > /opt/template.jsonnet
  /usr/local/bin/jsonnet /opt/template.jsonnet --ext-str id="${id}" -o /opt/"${component_name}".json
  cat /opt/"${component_name}".json
  /opt/parser.py "${component_name}" "/opt/${component_name}.json" /mnt/config
elif [ -e "/mnt/config/init/template.jsonnet" ]; then
  # new version of operator 2.0
  cat < /mnt/config/init/template.jsonnet | base64 -d > /mnt/config/template.jsonnet
  cat < /mnt/config/init/data.json | base64 -d > /mnt/config/data.json
  /opt/config.py "${pod_name}" /mnt/config/data.json /mnt/config/template.jsonnet /mnt/config/"${component_name}".json
  cat /mnt/config/"${component_name}".json
  /opt/parser.py "${component_name}" /mnt/config/"${component_name}".json /mnt/config
  # write to both locations to support image overrides
  mkdir -p /mnt/config/pod/"${pod_name}"
  /opt/parser.py "${component_name}" /mnt/config/"${component_name}".json /mnt/config/pod/"${pod_name}"
  # clean up excess output files
  rm /mnt/config/template.jsonnet /mnt/config/data.json /mnt/config/"${component_name}".json

  if [ "${OPERATOR_CP_TYPE}" = "connect" ] && [ -e "/mnt/config/shared/plugins.json" ]; then
    cat < /mnt/config/shared/plugins.json | base64 -d > /mnt/config/plugins.json
    /opt/generate_install_plugin_script.py /mnt/config/plugins.json /mnt/config/install_plugins.sh
    cat /mnt/config/install_plugins.sh
    echo "===> Installing connector plugins"
    /mnt/config/install_plugins.sh
    rm /mnt/config/install_plugins.sh /mnt/config/plugins.json
  fi
else
  echo "template.jsonnet not found in the path"
  exit 1
fi

# load scripts accordingly.
# The injected env variable OPERATOR_CP_TYPE and CP_COMPONENT_NAME needs to match for the below logic to work.
if [ -n "${OPERATOR_CP_TYPE}" ]; then
  echo "load script for CP type: ${OPERATOR_CP_TYPE}"
  cp -r /opt/confluentinc/"${OPERATOR_CP_TYPE}"/ /mnt/config/
fi
